User guide
==========

Depending on Chicken Turtle Util
--------------------------------
Because Chicken Turtle Util (CTU) offers such a wide variety of features, most of its dependencies
are optional so you only need to install the dependencies of the packages you
actually use.  To install all dependencies of the algorithms package for
example, use ``pip install chicken_turtle_util[algorithms]``.
If you are not familiar with pip, see `pip's quickstart guide
<https://pip.pypa.io/en/stable/quickstart/>`_.

..
  Configuration files
  -------------------

.. _mixins: https://en.wikipedia.org/wiki/Mixin
.. _click: http://click.pocoo.org/6/
